@@ -4,8 +4,9 @@ from __future__ import annotations
 
 from pywayland.server import Signal
 
-from wlroots import ffi, lib, Ptr
+from wlroots import Ptr, ffi, lib
 from wlroots.util.box import Box
+
 from .output import Output
 
 
@@ -89,17 +90,24 @@ class OutputLayout(Ptr):
         """Remove an output from the layout."""
         lib.wlr_output_layout_remove(self._ptr, output._ptr)
 
-    def get_box(self, reference: Output | None = None) -> Box:
+    def get_box(
+        self, reference: Output | None = None, dest_box: Box | None = None
+    ) -> Box:
         """
         Get the box of the layout for the given reference output in layout
         coordinates. If `reference` is None, the box will be for the extents of the
-        entire layout.
+        entire layout. If the output isn't in the layout, the box will be empty.
         """
         if reference:
-            box_ptr = lib.wlr_output_layout_get_box(self._ptr, reference._ptr)
+            reference_ptr = reference._ptr
         else:
-            box_ptr = lib.wlr_output_layout_get_box(self._ptr, ffi.NULL)
-        return Box(ptr=box_ptr)
+            reference_ptr = ffi.NULL
+
+        if not dest_box:
+            dest_box = Box(ptr=ffi.new("struct wlr_box *"))
+
+        lib.wlr_output_layout_get_box(self._ptr, reference_ptr, dest_box._ptr)
+        return dest_box
 
     def closest_point(
         self, lx: float, ly: float, reference: Output | None = None
